#
# Copyright 2010 Andrey Churin. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

import os
import sys
import datetime

from closurebuilder.util import ClosureCommand, Error, Command
from closurebuilder.metadata import Metadata
from closurebuilder.diff_match_patch import diff_match_patch

__all__ = ['ClosurePatchCommand']


class ClosurePatchCommand(ClosureCommand):
    """Creates patch from 2 files and writes it to the third file (or console)"""
    summary = __doc__

    min_args = 2
    max_args = 3

    default_verbosity = 3

    group_name = 'Closure'

    parser = Command.standard_parser(simulate=True)

    def command_execute(self):
        diff = diff_match_patch()
        file1 = os.path.join(os.getcwd(), self.args[0])
        file2 = os.path.join(os.getcwd(), self.args[1])
        if len(self.args) > 2:
          output = os.path.join(os.getcwd(), self.args[2])
        else:
          output = None

        if not os.isfile(file1):
          raise Error('File %s not found'%self.args[0])

        if not os.isfile(file2):
          raise Error('File %s not found'%self.args[1])
          
        patches = diff.patch_make(open(file1).read(), open(file2).read())
        result = patch_toText(patches)
        
        if output:
          f = open(output, 'wt')
          f.write(result)
          f.close()
        else:
          print result

